@@ -1,8 +1,7 @@
 //! Validations for various accounts.
 
 use anchor_lang::prelude::*;
-use vipers::assert_keys;
-use vipers::validate::Validate;
+use vipers::{assert_keys_eq, validate::Validate};
 
 use crate::{NewRegistry, SyncQuarry};
 
@@ -14,7 +13,7 @@ impl<'info> Validate<'info> for NewRegistry<'info> {
 
 impl<'info> Validate<'info> for SyncQuarry<'info> {
     fn validate(&self) -> ProgramResult {
-        assert_keys!(
+        assert_keys_eq!(
             self.quarry.rewarder_key,
             self.registry.rewarder,
             "quarry.rewarder_key"
